@@ -2,4 +2,6 @@
 // Use of this source is governed by Apache-2.0 License that can be found
 // in the LICENSE file.
 
+pub mod arch;
 pub mod expand_env;
+pub mod str;
