@@ -2,18 +2,22 @@
 // Use of this source is governed by Apache-2.0 License that can be found
 // in the LICENSE file.
 
-pub use nc::mode_t;
-// TODO(Shaohua): Remove Errno
-pub use nc::Errno;
-
 pub mod core;
 
+pub mod arch;
 pub mod cp;
 pub mod error;
 pub mod hashsum;
+pub mod head;
 pub mod ln;
 pub mod ls;
 pub mod mkdir;
 pub mod mv;
+pub mod nice;
+pub mod renice;
 pub mod rm;
+pub mod sleep;
+pub mod sync;
+pub mod uname;
+pub mod uptime;
 pub mod whoami;
