@@ -2,20 +2,23 @@
 // Use of this source is governed by Apache-2.0 License that can be found
 // in the LICENSE file.
 
-extern crate glob;
-extern crate nc;
-
-use nc::mode_t;
-use nc::Errno;
 use std::path::Path;
 
 use crate::core::expand_env::expand_env;
+use crate::error::Error;
 
 #[derive(Debug)]
 pub struct Options {
-    pub recursive: bool,
-    pub mode: mode_t,
+    /// No error if existing, make parent directories as needed.
+    /// Just like `mkdir -p` command.
+    pub parents: bool,
+
+    /// Set file mode (as in chmod), not a=rwx - umask.
+    pub mode: nc::mode_t,
+
+    /// No error if existing.
     pub exist_ok: bool,
+
     pub expand_env: bool,
 }
 
@@ -28,7 +31,7 @@ impl Options {
 impl Default for Options {
     fn default() -> Self {
         Options {
-            recursive: false,
+            parents: false,
             mode: 0o755,
             exist_ok: false,
             expand_env: true,
@@ -36,13 +39,21 @@ impl Default for Options {
     }
 }
 
-// TODO(Shaohua): Wrap Errno with local Error type
+impl Options {
+    pub fn with_parents() -> Self {
+        Self {
+            parents: true,
+            ..Self::default()
+        }
+    }
+}
+
 /// Make directories like `mkdir` command.
-pub fn mkdir<T: AsRef<str>>(directory: T, options: &Options) -> Result<(), Errno> {
-    let exist_ok = if options.recursive {
+pub fn mkdir<T: AsRef<str>>(directory: T, options: &Options) -> Result<(), Error> {
+    let exist_ok = if options.parents {
         true
     } else {
-        options.recursive
+        options.parents
     };
 
     let directory = if options.expand_env {
@@ -52,10 +63,10 @@ pub fn mkdir<T: AsRef<str>>(directory: T, options: &Options) -> Result<(), Errno
     };
 
     let path = Path::new(&directory);
-    do_mkdir(path, options.recursive, options.mode, exist_ok)
+    do_mkdir(path, options.parents, options.mode, exist_ok).map_err(Into::into)
 }
 
-fn do_mkdir(p: &Path, recursive: bool, mode: mode_t, exist_ok: bool) -> Result<(), Errno> {
+fn do_mkdir(p: &Path, recursive: bool, mode: nc::mode_t, exist_ok: bool) -> Result<(), nc::Errno> {
     if p.exists() {
         if exist_ok {
             return Ok(());
@@ -70,7 +81,6 @@ fn do_mkdir(p: &Path, recursive: bool, mode: mode_t, exist_ok: bool) -> Result<(
         }
     }
 
-    let p = p.to_str().unwrap();
     nc::mkdir(p, mode)
 }
 
@@ -81,8 +91,8 @@ mod tests {
     #[test]
     fn test_mkdir() {
         let mut options = Options::new();
-        options.recursive = true;
+        options.parents = true;
         let ret = mkdir("/tmp/test1/test2", &options);
-        assert_eq!(ret, Ok(()));
+        assert!(ret.is_ok());
     }
 }
